@@ -1,6 +1,5 @@
-
 from django.apps import AppConfig
-from django.db import OperationalError
+from django.db import DatabaseError
 
 
 class DjangoWireguardConfig(AppConfig):
@@ -8,11 +7,15 @@ class DjangoWireguardConfig(AppConfig):
     verbose_name = "Django WireGuard"
 
     def ready(self):
-        # noinspection PyUnresolvedReferences
+        """
+        Sync WireGuard interfaces with system's.
+
+        Does nothing if any DatabaseError arises.
+        """
         from django_wireguard.sync_wg import sync_wireguard_interfaces
         try:
             sync_wireguard_interfaces()
-        except OperationalError:
+        except DatabaseError:
             pass
 
 
