@@ -8,11 +8,16 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         group = parser.add_mutually_exclusive_group()
-        group.add_argument('pubkeys', type=str, nargs='+', help="peer's public key")
-        group.add_argument('--all', action='store_true', help="delete all peers")
+        group.add_argument('pubkey',
+                           type=str,
+                           nargs='*',
+                           help="Peer Public Key(s)")
+        group.add_argument('--all',
+                           action='store_true',
+                           help="Delete all peers")
 
     def handle(self, *args, **options):
-        public_keys = options['pubkeys']
+        public_keys = options['pubkey']
         delete_all = options['all']
 
         if delete_all:
