@@ -6,6 +6,12 @@ from django_wireguard.models import WireguardInterface
 
 
 def sync_wireguard_interfaces(queryset: Optional[Union[QuerySet, WireguardInterface]] = None):
+    """
+    Sync database WireguardInterface queryset or instance to WireGuard devices on the system.
+
+    :param queryset: WireguardInterfaces to sync with the system
+    :type queryset: WireguardInterface queryset or instance
+    """
     if queryset is None:
         queryset = WireguardInterface.objects.all()
     elif isinstance(queryset, WireguardInterface):
