@@ -2,7 +2,8 @@ from typing import List
 
 
 def purge_private_keys() -> int:
-    """Purge all Private Key from database.
+    """
+    Purge all Private Key from database.
 
     :return: Removed keys count.
     """
@@ -16,13 +17,26 @@ def purge_private_keys() -> int:
 
 
 def clean_comma_separated_list(value: str) -> List[str]:
+    """
+    Clean comma separated list of values.
+
+    Removes all spaces and newlines (CR, CRLF, LF chars).
+    Removes trailing commas.
+    Returns empty list if string is empty after evaluation.
+
+    :value: comma-separated list of values
+    :type value: str
+    :return: list of values separated and trimmed from input
+    :rtype: list
+    """
     values = (value
               .replace(' ', '')
-              .replace('\n\r', '')
+              .replace('\r', '')
               .replace('\n', '')
+              .rstrip(',')
               .split(','))
 
-    if '' in values:
-        values.remove('')
+    if values == ['']:
+        return []
 
     return values
