@@ -1,11 +1,19 @@
 import ipaddress
+from typing import Union
 
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import ValidationError
 from django_wireguard.wireguard import PrivateKey, PublicKey
 
 
-def validate_private_ipv4(value):
+def validate_private_ipv4(value: str):
+    """
+    Validate private IPv4 address.
+
+    :param value: Value to validate
+    :type value: str
+    :raises: ValidationError if value provided is not a valid IPv4 address
+    """
     try:
         ip_address = ipaddress.IPv4Address(value)
         if not ip_address.is_private or ip_address.is_unspecified:
@@ -17,7 +25,14 @@ def validate_private_ipv4(value):
         )
 
 
-def validate_allowed_ips(value):
+def validate_allowed_ips(value: str):
+    """
+    Validate comma-separated list of allowed_ips (IPv4 interfaces).
+
+    :param value: Value to validate
+    :type value: str
+    :raises: ValidationError if value provided is not a valid list of IPv4 interfaces
+    """
     for ip in value.split(','):
         try:
             ip_address = ipaddress.IPv4Interface(ip)
@@ -30,7 +45,13 @@ def validate_allowed_ips(value):
             )
 
 
-def validate_wireguard_private_key(value):
+def validate_wireguard_private_key(value: str):
+    """
+    Validate base64 encoded private key.
+
+    :param value: Value to validate
+    :raises: ValidationError if value provided is not a valid private key
+    """
     try:
         PrivateKey(value)
     except ValueError:
@@ -40,6 +61,12 @@ def validate_wireguard_private_key(value):
 
 
 def validate_wireguard_public_key(value):
+    """
+    Validate base64 encoded public key.
+
+    :param value: Value to validate
+    :raises: ValidationError if value provided is not a valid public key
+    """
     try:
         PublicKey(value)
     except ValueError:
